# PaymentServiceDefinitionSupportedFeatures

Features supported by the payment definition.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**payment_method_tokenization** | **bool** | Supports storing a payment method via tokenization. | [optional] 
**three_d_secure_hosted** | **bool** | Supports hosted 3-D Secure with a redirect. | [optional] 
**three_d_secure_pass_through** | **bool** | Supports passing 3-D Secure data to the underlying processor. | [optional] 
**apple_pay** | **bool** | Supports passing decrypted apple pay token to the underlying processor. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


